import numpy as np
import pylab
from lmfit import Minimizer, Parameters, fit_report

#nacteni dat do matice
data=np.loadtxt('Data.dat')  
xdata=data[:,0]
ydata=data[:,1]

def gaussian(x,p,w,g):
    return p/(g*2*np.pi) * np.exp(-(x-w)**2/(2*g**2))

#definice residualu: rozdilu fitovane funkce a dat
def residual(params, x, ydata):
    v = params.valuesdict()    #rozbaleni parametru do slovniku v
    lumi=gaussian(x, v['p'], v['w'],v['g'])
    #e = v['eINF']-v['w']**2/(x*(x+1j*v['g']))  #dielektricka funkce
    return lumi-ydata    

#vytvoreni parametru a jejich startovacich hodnot. Mozno nastavit, zda se parametr fituje (vary=True) nebo ne 
params = Parameters()
params.add('p', value=8104,vary=True)
params.add('w', value=2,vary=True)
params.add('g', value=0.06597753,vary=True)

#fitovani
minner = Minimizer(residual, params, fcn_args=(xdata,ydata))
result = minner.minimize(method='leastsq')

# calculate final result: data + residual
final = ydata + result.residual

# write error report, alternative result.params.pretty_print()
print(fit_report(result))

#ulozeni nafitovaneho spektra do souboru
FileData= open('Spektrum.dat', 'w')
for i in range(len(xdata)):
    print (xdata[i], "\t",final[i], file=FileData)

#ulozeni statistiky do souboru
FileFit = open('Statistika.dat', 'w')
print (fit_report(result), file=FileFit)


# vykresleni fitu na monitor
original= ydata+residual(params,xdata,ydata)
pylab.plot(xdata, original, 'g-', label='Original model')
pylab.plot(xdata, ydata, 'k-', label='data')
pylab.plot(xdata, final, 'r-', label='Fitted model')
legend = pylab.legend(loc='upper right', shadow=False, fontsize='x-small')
pylab.show()

