import numpy as np
from scipy.special import wofz
import pylab

def G(x, x0, alpha):
    """ Return Gaussian line shape at x with HWHM alpha """
    return np.sqrt(np.log(2)/np.pi)/alpha*np.exp(-((x-x0)/alpha)**2 * np.log(2))

def L(x, x0, gamma):
	""" Return Lorentzian line shape at x with HWHM gamma """
	#return gamma / np.pi / ((x-x0)**2 + (2*gamma)**2)
	return 1/((x-x0)**2 + (2*gamma)**2)

def LCompl(x, x0, gamma):
	""" Return Lorentzian line shape at x with HWHM gamma """
	return  np.pi* 2*gamma  / (x0**2- x**2 - 1J*2*gamma*x)
	#return  1/(x**2 - x0**2 - 1J*2*gamma*x)/np.sqrt(np.pi)


def V(x,x0, alpha, gamma):
    """
    Return the Voigt line shape at x with Lorentzian component HWHM gamma
    and Gaussian component HWHM alpha using the Faddeeva function wofz

    """
    sigma = alpha / np.sqrt(2 * np.log(2))

    return np. conj(wofz((x-x0+1j*gamma)/sigma/np.sqrt(2)) /sigma/np.sqrt(2*np.pi)-\
		   wofz((x+x0+1j*gamma)/sigma/np.sqrt(2)) /sigma/np.sqrt(2*np.pi))

alpha, gamma, x0 = 0.1, 0.1 , 1
x = np.linspace(-2,2,1000)
pylab.plot(x, G(x, x0, alpha), ls=':', label='Gaussian')
pylab.plot(x, np.real(LCompl(x,x0,gamma)), ls='--', label='Re Lor')
pylab.plot(x, np.imag(LCompl(x,x0,gamma)), ls='--', label='Im Lor')
pylab.plot(x, np.real(V(x, x0, 0.0001*alpha, gamma)), label='Re Voigt Lorentzian limit')
pylab.plot(x, np.imag(V(x, x0, 0.0001*alpha, gamma)), label='Im Voigt Lorentzian limit')
#pylab.xlim(0,2)
pylab.legend()
pylab.show()

pylab.plot(x, G(x, x0, alpha), ls=':', linewidth=4.0, label='Gaussian')
pylab.plot(x, np.real(LCompl(x,x0,gamma)), ls='--', label='Re Lor')
pylab.plot(x, np.imag(LCompl(x,x0,gamma)), ls='--', label='Im Lor')
pylab.plot(x, np.real(V(x, x0, alpha, 0*gamma)), label='Re Voigt Gaussian limit')
pylab.plot(x, np.imag(V(x, x0, alpha, 0*gamma)), label='Im Voigt Gaussian limit')
#pylab.xlim(0,2)
pylab.legend()
pylab.show()

